@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 __author__ = ('Duy Tin Truong (duytin.truong@unitn.it), '
               'Aitor Blanco Miguez (aitor.blancomiguez@unitn.it)')
-__version__ = '3.1.0'
-__date__    = '25 Jul 2021'
+__version__ = '4.0.0'
+__date__    = '22 Aug 2022'
 
 import argparse as ap
 import pandas
